import { SObjectItem, SImageItem, SGraphItem, STextItem } from "@saga-web/graph/lib";
import { ItemOrder } from "@saga-web/big/lib";
import { SColor, SPainter, SRect } from "@saga-web/draw/lib";
import { SMouseEvent } from "@saga-web/base/lib";
import { EquipmentData } from "../types/EquipmentData";
export class SEquipmentItem extends SObjectItem {
    // img对象
    img: SImageItem = new SImageItem(this);
    textArr: STextItem[] = [];
    /** imgkey值 */
    _imgKey: string = "";
    get imgKey(): string {
        return this._imgKey;
    }
    set imgKey(v: string) {
        this._imgKey = v;
        this.img.url = `http://localhost:8091/serve/topology-wanda/Picture/query/${v}`;
        this.update();
    }
    /**
     *
     * @param parent 父类
     * @param textInfo  需要展示的节点信息
     */
    constructor(parent: SGraphItem | null, textInfo?: EquipmentData) {
        super(parent);
        console.log(textInfo);
        this.img.url = `http://localhost:8091/serve/topology-wanda/Picture/query/14d978b7edd346f088d6cfb53ada4070`;
        this.img.width = 24;
        this.img.height = 24;
        this.moveable = true;
        this.zOrder = ItemOrder.textOrder;
        this.textArr = [];
        /*  if (textInfo) {
            let x = textInfo.Pos.X;
            let y = textInfo.Pos.Y;
            this.x = x;
            this.y = y;
        } */
        // 有信息点信息时,绘制信息点信息
        if (textInfo) {
            let index = 0;
            for (let key in textInfo) {
                let textItem = new STextItem(this);
                textItem.moveable = true;
                textItem.backgroundColor = SColor.White;
                textItem.font.size = 14;
                textItem.moveTo(17, index * 20 - 10);
                // @ts-ignore
                textItem.text = `${key} : ${textInfo[key]}`;
                this.textArr.push(textItem);
                index++;
            }
        }
    }

    /**
     * 宽高发生变化
     *
     * @return  SRect   所有子对象的并集
     * */
    boundingRect(): SRect {
        //  return new SRect(-this.width / 2, -this.height / 2, this.width, this.height);
        let rect = this.img.boundingRect().adjusted(this.img.pos.x, this.img.pos.y, 0, 0);
        if (this.textArr.length) {
            for (let text of this.textArr) {
                rect = rect.unioned(text.boundingRect().adjusted(text.pos.x, text.pos.y, 0, 0));
            }
        }
        return rect.adjusted(-5, -5, 10, 10);
    } // Function boundingRect()

    /**
     * Item绘制操作
     *
     * @param   painter painter对象
     */
    onDraw(painter: SPainter): void {
        painter.pen.lineWidth = painter.toPx(1);
        painter.pen.color = SColor.Black;
        painter.brush.color = SColor.White;
        painter.drawRect(this.boundingRect());
    } // Function onDraw()
}
